@@ -9,17 +9,17 @@ Code Examples:
 
 		Generate a random safe fact.
 
-			>>> randfacts.getFact()
+			>>> randfacts.get_fact()
 
 		Generate a random unsafe fact.
 
-			>>> randfacts.getFact(only_unsafe=True)
+			>>> randfacts.get_fact(only_unsafe=True)
 
 		Generate a random mixed fact (possibility of both safe and unsafe facts)
 
-			>>> randfacts.getFact(False)
+			>>> randfacts.get_fact(False)
 			>>> # or
-			>>> randfacts.getFact(filter_enabled=False)
+			>>> randfacts.get_fact(filter_enabled=False)
 
 CLI Examples:
 	randfacts can be executed via the command line with the following commands:
@@ -43,4 +43,11 @@ CLI Examples:
 """
 
 from .__version__ import __title__, __description__, __url__, __version__, __author__, __author_email__, __license__, __copyright__
-from randfacts.randfacts import getFact, safeFacts, unsafeFacts, allFacts
+from randfacts.randfacts import get_fact, safe_facts, unsafe_facts, all_facts
+
+import warnings as _warnings
+# Deprecated methods
+def getFact(filter_enabled=True, only_unsafe=False):
+	"""This method is deprecated. Please use get_fact"""
+	_warnings.warn("getFact is deprecated. Please use get_fact", DeprecationWarning, stacklevel=2)
+	return get_fact(filter_enabled, only_unsafe)
